#!/bin/sh
# Name: CCcam-Config_2.0.10_081110.tar.gz
# Version: 2.0.10
# Type: cam-config

rm -rf /var/etc/CCcam.cfg
rm -rf /var/etc/CCcam.channelinfo
rm -rf /var/etc/CCcam.prio
rm -rf /var/etc/CCcam.providers
rm -rf /var/uninstall/CCcam-Config_2.0.10_delfile.sh

exit 0

######################################
####### Powered by Gemini Team #######
## http://www.i-have-a-dreambox.com ##
######################################
